==> kubernetes-model-core-4.13.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/SecretEnvSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class SecretEnvSourceFluentImpl<A extends SecretEnvSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements SecretEnvSourceFluent<A> {

    private String name;
    private Boolean optional;

    public SecretEnvSourceFluentImpl() { 
    }


    public SecretEnvSourceFluentImpl(SecretEnvSource instance) { 
        this.withName(instance.getName()); 
        this.withOptional(instance.getOptional()); 
    }


    public String getName() {
        return this.name;
    }

    public A withName(String name) {
        this.name=name; return (A) this;
    }

    public Boolean hasName() {
        return this.name != null;
    }

    public A withNewName(String arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuilder arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1) {
        return (A)withName(new String(arg1));
    }

    public Boolean isOptional() {
        return this.optional;
    }

    public A withOptional(Boolean optional) {
        this.optional=optional; return (A) this;
    }

    public Boolean hasOptional() {
        return this.optional != null;
    }

    public A withNewOptional(String arg1) {
        return (A)withOptional(new Boolean(arg1));
    }

    public A withNewOptional(boolean arg1) {
        return (A)withOptional(new Boolean(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        SecretEnvSourceFluentImpl that = (SecretEnvSourceFluentImpl) o;
        if (name != null ? !name.equals(that.name) :that.name != null) return false;
        if (optional != null ? !optional.equals(that.optional) :that.optional != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(name,  optional,  super.hashCode());
    }

}

==> kubernetes-model-core-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/SecretEnvSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class SecretEnvSourceFluentImpl<A extends SecretEnvSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements SecretEnvSourceFluent<A> {

    private String name;
    private Boolean optional;

    public SecretEnvSourceFluentImpl() {
    }

    public SecretEnvSourceFluentImpl(SecretEnvSource instance) {
        this.withName(instance.getName()); 
        this.withOptional(instance.getOptional()); 
    }

    public String getName() {
        return this.name;
    }

    public A withName(String name) {
        this.name=name; return (A) this;
    }

    public Boolean hasName() {
        return this.name != null;
    }

    public A withNewName(StringBuilder arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(int[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(char[] arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(byte[] arg1,int arg2) {
        return (A)withName(new String(arg1, arg2));
    }

    public A withNewName(byte[] arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(char[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(byte[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withName(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewName(String arg1) {
        return (A)withName(new String(arg1));
    }

    public Boolean getOptional() {
        return this.optional;
    }

    public A withOptional(Boolean optional) {
        this.optional=optional; return (A) this;
    }

    public Boolean hasOptional() {
        return this.optional != null;
    }

    public A withNewOptional(String arg1) {
        return (A)withOptional(new Boolean(arg1));
    }

    public A withNewOptional(boolean arg1) {
        return (A)withOptional(new Boolean(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        SecretEnvSourceFluentImpl that = (SecretEnvSourceFluentImpl) o;
        if (name != null ? !name.equals(that.name) :that.name != null) return false;
        if (optional != null ? !optional.equals(that.optional) :that.optional != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(name,  optional,  super.hashCode());
    }

}
